import { LoginRequest, LoginResponse, EIACDesktopApi, ApiResponse } from './EIAC_Desktop_Api';

/**
 * 登录处理函数
 */
async function handleLogin(request: LoginRequest): Promise<void> {
    const errorMessage = document.getElementById('errorMessage') as HTMLDivElement;

    if (!request.Account || !request.Password) {
        errorMessage.style.display = 'block';
        errorMessage.textContent = '请输入账号和密码';
        return;
    }

    try {
        const response: ApiResponse<LoginResponse> = await EIACDesktopApi.Auth.LoginAsync(request);
        if (response.status !== 0) {
            errorMessage.style.display = 'block';
            errorMessage.textContent = response.msg || '登录失败';
        } else {
            // 登录成功，将data.Cookies拼接为字符串，存储cookie
            const cookies: string = JSON.stringify(response.data.Cookies);
            window.electronAPI.setSessionStorage('cookie', cookies);
            // 跳转到主页面
            window.location.href = 'index.html';
        }
    } catch (error) {
        errorMessage.style.display = 'block';
        errorMessage.textContent = '网络错误，请稍后重试。错误原因：' + error;
        console.error('登录失败:', error);
    }
}

/**
 * 页面加载完成后绑定事件
 */
document.addEventListener('DOMContentLoaded', async () => {
    const loginButton = document.getElementById('btnLogin');
    if (loginButton) {
        loginButton.addEventListener('click', async () => {
            const account = (document.getElementById('txtAccount') as HTMLInputElement).value;
            const password = (document.getElementById('txtPassword') as HTMLInputElement).value;
            await handleLogin({ Account: account, Password: password });
        });
    }
}); 